==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/InputBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
import { InputBaseDirection_$type } from "./InputBaseDirection";
import { InputBaseSelectMode_$type } from "./InputBaseSelectMode";
/**
 * @hidden
 */
var InputBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(InputBase, _super);
    function InputBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.l = null;
        _this.inputOcurred = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    Object.defineProperty(InputBase.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "nativeElement", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e.o = this.l;
        },
        enumerable: false,
        configurable: true
    });
    InputBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(InputBase.prototype, "i", {
        get: function () {
            var ret_ = this.f.n("outlined");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("outlined", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "j", {
        get: function () {
            var ret_ = this.f.n("readOnly");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("readOnly", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "o", {
        get: function () {
            var ret_ = this.f.n("placeholder");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("placeholder", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "n", {
        get: function () {
            var ret_ = this.f.n("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "b", {
        get: function () {
            var ret_ = this.f.n("size");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "g", {
        get: function () {
            var ret_ = this.f.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "k", {
        get: function () {
            var ret_ = this.f.n("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "h", {
        get: function () {
            var ret_ = this.f.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    InputBase.prototype.inputOcurredChanged = function () {
        var _this = this;
        if (this.inputOcurred != null) {
            this.f.r("input", function (a) { return _this.inputOcurred(_this, ComponentValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("input");
        }
    };
    InputBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.f.r("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.u("focus");
        }
    };
    InputBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.f.r("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.u("blur");
        }
    };
    InputBase.prototype.s = function () {
        this.nativeElement.connectedCallback();
    };
    InputBase.prototype.t = function () {
        this.nativeElement.disconnectedCallback();
    };
    InputBase.prototype.v = function (a) {
        this.nativeElement.focus(this.f.i(a));
    };
    InputBase.prototype.q = function () {
        this.nativeElement.blur();
    };
    InputBase.prototype.ab = function (a, b, c) {
        this.nativeElement.setSelectionRange(this.f.i(a), this.f.i(b), this.f.i(enumGetBox(InputBaseDirection_$type, c)));
    };
    InputBase.prototype.aa = function (a, b, c, d) {
        this.nativeElement.setRangeText(this.f.i(a), this.f.i(b), this.f.i(c), this.f.i(enumGetBox(InputBaseSelectMode_$type, d)));
    };
    InputBase.prototype.x = function () {
        this.nativeElement.reportValidity();
    };
    InputBase.prototype.r = function () {
        this.nativeElement.checkValidity();
    };
    InputBase.prototype.y = function (a) {
        this.nativeElement.setCustomValidity(this.f.i(a));
    };
    InputBase.$t = markType(InputBase, 'InputBase', BaseElement.$);
    return InputBase;
}(BaseElement));
export { InputBase };

==> igniteui-react-18.6.1-beta.0.tgz: package/esm5/lib/InputBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
import { InputBaseDirection_$type } from "./InputBaseDirection";
import { InputBaseSelectMode_$type } from "./InputBaseSelectMode";
/**
 * @hidden
 */
var InputBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(InputBase, _super);
    function InputBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.f = new WCNativeHelper();
        _this.n = null;
        _this.inputOcurred = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    Object.defineProperty(InputBase.prototype, "g", {
        get: function () {
            return this.f;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "nativeElement", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.f.o = this.n;
        },
        enumerable: false,
        configurable: true
    });
    InputBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(InputBase.prototype, "j", {
        get: function () {
            var ret_ = this.g.n("outlined");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("outlined", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "l", {
        get: function () {
            var ret_ = this.g.n("readOnly");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("readOnly", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "k", {
        get: function () {
            var ret_ = this.g.n("readonly");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("readonly", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "r", {
        get: function () {
            var ret_ = this.g.n("placeholder");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("placeholder", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "p", {
        get: function () {
            var ret_ = this.g.n("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "c", {
        get: function () {
            var ret_ = this.g.n("size");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.g.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.g.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "h", {
        get: function () {
            var ret_ = this.g.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "m", {
        get: function () {
            var ret_ = this.g.n("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "q", {
        get: function () {
            var ret_ = this.g.n("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(InputBase.prototype, "i", {
        get: function () {
            var ret_ = this.g.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.g.v("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    InputBase.prototype.inputOcurredChanged = function () {
        var _this = this;
        if (this.inputOcurred != null) {
            this.g.r("input", function (a) { return _this.inputOcurred(_this, ComponentValueChangedEventArgs.a(a)); });
        }
        else {
            this.g.u("input");
        }
    };
    InputBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.g.r("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.g.u("focus");
        }
    };
    InputBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.g.r("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.g.u("blur");
        }
    };
    InputBase.prototype.v = function () {
        this.nativeElement.connectedCallback();
    };
    InputBase.prototype.w = function () {
        this.nativeElement.disconnectedCallback();
    };
    InputBase.prototype.y = function (a) {
        this.nativeElement.focus(this.g.i(a));
    };
    InputBase.prototype.t = function () {
        this.nativeElement.blur();
    };
    InputBase.prototype.ae = function (a, b, c) {
        this.nativeElement.setSelectionRange(this.g.i(a), this.g.i(b), this.g.i(enumGetBox(InputBaseDirection_$type, c)));
    };
    InputBase.prototype.ad = function (a, b, c, d) {
        this.nativeElement.setRangeText(this.g.i(a), this.g.i(b), this.g.i(c), this.g.i(enumGetBox(InputBaseSelectMode_$type, d)));
    };
    InputBase.prototype.aa = function () {
        this.nativeElement.reportValidity();
    };
    InputBase.prototype.u = function () {
        this.nativeElement.checkValidity();
    };
    InputBase.prototype.ab = function (a) {
        this.nativeElement.setCustomValidity(this.g.i(a));
    };
    InputBase.$t = markType(InputBase, 'InputBase', BaseElement.$);
    InputBase.__marshalByValueIgnore = ["readonly"];
    return InputBase;
}(BaseElement));
export { InputBase };
